==> phplist-2.10.5p0.tgz: lists/admin/about.php <==
<div align=center>
<table width="75%" border=1 cellspacing=5 cellpadding=5>
<tr><td colspan="2" class="abouthead"><?php echo NAME?></td></tr>
<tr><td width=50 valign=top>Powered by <a href="http://www.phplist.com" target="_blank">phplist</a>, version <?php echo VERSION?> <a href="http://www.phplist.com" target="_blank"><br/><br/><img src="../images/power-phplist.png" width=70 height=30 border=0></a></td>
<td valign=top>
phplist is licensed with the <a href="http://www.gnu.org/copyleft" target="_blank">GNU Public License (GPL)</a>.
<br/>
Copyright &copy; 2000-<?php echo date('Y')?> <a href="http://tincan.co.uk" target="_blank">Tincan Ltd.</a>
<br/>
<br/>
<b><?php echo $GLOBALS['I18N']->get('Developers')?></b>:<ul>
<li>Michiel Dethmers, Tincan Ltd</li>
</ul>
<b><?php echo $GLOBALS['I18N']->get('Contributors')?></b><ul>
<li>Damien McKenna</li>
<li>Pete Ness, Nessoft LLC</li>
<li>Xavier Dutoit, Sydesy</li>
<li>and many others</li>
</ul>
<b><a href="http://docs.phplist.com" target="_blank"><?php echo $GLOBALS['I18N']->get('Documentation')?></a></b><ul>
<li>Yan Brailowsky</li>
<li><!--a href="http://pascal.vanhecke.info/" target="_blank"-->Pascal Van Hecke<!--/a--></li>
</ul>

<b><?php echo $GLOBALS['I18N']->get('Translations') ?></b><ul>
<li><a href="http://www.babels.org" target="_blank">Babels</a></li>
<?php echo $GLOBALS['I18N']->get('credits for this translation') ?>
</ul>
<p><?php echo $GLOBALS['I18N']->get('thankseveryone')?></p>

<b><?php echo $GLOBALS['I18N']->get('Portions of the system include')?></b>
<ul>
<li><a href="http://www.webbler.org" target="_blank">Webbler</a> code, by <a href="http://tincan.co.uk" target="_blank">Michiel Dethmers</a>
<li>Onyx-RSS, by Ed Swindelles</li>
<li><a href="http://www.fckeditor.net/" target="_blank">FCKeditor</a>, by Frederico Caldeira Knabben and team</li>
<li>the <a href="http://phpmailer.sourceforge.net/" target="_blank">phpmailer</a> class </li>
<li>The html email class from, <a href="http://www.phpguru.org/" target="_blank">Richard Heyes</a></li>
</tr></table>
</div>
<!-- some google bombing, who knows, might work :-) -->
<div style="display:none">
<a href="http://www.phplist.com">Newsletter</a><a href="http://www.phplist.com">Newsletter Manager</a><a href="http://www.phplist.com">Open Source Newsletter</a><a href="http://www.phplist.com">Open Source Newsletter Manager</a><a href="http://www.phplist.com">Opt In</a><a href="http://www.phplist.com">Opt In Marketing</a><a href="http://www.phplist.com">Double Opt In Marketing</a><a href="http://www.phplist.com">Newsletter Software</a><a href="http://www.phplist.com">Mailinglist</a><a href="http://www.phplist.com">Permission Marketing</a>
</div>

==> phplist-2.10.19p0.tgz: lists/admin/about.php <==
<div align=center>
<table width="75%" border=1 cellspacing=5 cellpadding=5>
<tr><td colspan="2" class="abouthead"><?php echo NAME?></td></tr>
<tr><td width=50 valign=top>Powered by <a href="http://www.phplist.com" target="_blank">phplist</a>, version <?php echo VERSION?> <a href="http://www.phplist.com" target="_blank"><br/><br/><img src="../images/power-phplist.png" width=70 height=30 border=0></a></td>
<td valign=top>
phplist is licensed with the <a href="http://www.gnu.org/copyleft" target="_blank">GNU Public License (GPL)</a>.
<br/>
Copyright &copy; 2000-<?php echo date('Y')?> <a href="http://phplist.com" target="_blank">phpList Ltd.</a>
<br/>
<br/>
<b><?php echo $GLOBALS['I18N']->get('Developers')?></b>:<ul>
<li>Michiel Dethmers, phpList Ltd</li>
</ul>
<b><?php echo $GLOBALS['I18N']->get('Contributors')?></b><ul>
<li>Damien McKenna</li>
<li>Pete Ness, Nessoft LLC</li>
<li>Xavier Dutoit, Sydesy</li>
<li>and many others</li>
</ul>
<b><a href="http://docs.phplist.com" target="_blank"><?php echo $GLOBALS['I18N']->get('Documentation')?></a></b><ul>
<li>Yan Brailowsky</li>
<li><!--a href="http://pascal.vanhecke.info/" target="_blank"-->Pascal Van Hecke<!--/a--></li>
</ul>

<b><?php echo $GLOBALS['I18N']->get('Translations') ?></b><ul>
<li><a href="http://www.babels.org" target="_blank">Babels</a></li>
<?php echo $GLOBALS['I18N']->get('credits for this translation') ?>
</ul>
<p><?php echo $GLOBALS['I18N']->get('thankseveryone')?></p>

<b><?php echo $GLOBALS['I18N']->get('Portions of the system include')?></b>
<ul>
<li><a href="http://www.webbler.org" target="_blank">Webbler</a> code, by <a href="http://phplist.com" target="_blank">Michiel Dethmers</a>
<li>Onyx-RSS, by Ed Swindelles</li>
<li><a href="http://www.fckeditor.net/" target="_blank">FCKeditor</a>, by Frederico Caldeira Knabben and team</li>
<li>the <a href="http://phpmailer.sourceforge.net/" target="_blank">phpmailer</a> class </li>
<li>The html email class from, <a href="http://www.phpguru.org/" target="_blank">Richard Heyes</a></li>
</tr></table>
</div>
<!-- some google bombing, who knows, might work :-) -->
<div style="display:none">
<a href="http://www.phplist.com">Newsletter</a><a href="http://www.phplist.com">Newsletter Manager</a><a href="http://www.phplist.com">Open Source Newsletter</a><a href="http://www.phplist.com">Open Source Newsletter Manager</a><a href="http://www.phplist.com">Opt In</a><a href="http://www.phplist.com">Opt In Marketing</a><a href="http://www.phplist.com">Double Opt In Marketing</a><a href="http://www.phplist.com">Newsletter Software</a><a href="http://www.phplist.com">Mailinglist</a><a href="http://www.phplist.com">Permission Marketing</a>
</div>
